"use strict";

const server = require("./setup");
const assert = require('chai').assert;
const hl = require('highland');
const db = require('tm-apps-db')(require('config').db);
let utils = require("./utils");

describe("Get Section Id Component", () => {

    const newSection = {
        "escenic_id": 71,
        "source": "nationals",
        "name": 'new section',
        "url": "url",
        "id": 'nationals.71',
        "publication_id": 'nationals.2'
    };

    const news = {
        "escenic_id": 72,
        "source": "nationals",
        "name": 'News',
        "url": "url",
        "id": 'nationals.72',
        "publication_id": 'nationals.2'
    };

    before(done => {
        hl(utils.given(db, 'section', newSection))
            .flatMap(() => hl(utils.given(db, "section", news)))
            .toCallback(done);
    });

    it("Regex returns a section", (done) => {
        server
            .get("/nationals/2/section-ids?filter=new s")
            .end((err, res) => {
                assert.equal(res.body.length, 1);
                assert.equal(res.body[0].source, "nationals");
                assert.equal(res.body[0].escenic_id, 71);
                assert.equal(res.body[0].name, "new section");
                done();
            });
    });

    it("Regex fails to return a section", (done) => {
        server
            .get("/nationals/2/section-ids?filter=newdsf s")
            .end((err, res) => {
                assert.deepEqual(res.body, []);
                done();
            });
    });

    it("gives back all sections for a publication", (done) => {
        server
            .get("/nationals/2/section-ids")
            .end((err, res) => {
                assert.equal(res.body.length, 2);
                done();
            });
    });
});


describe("Get tag Id Component", () => {

    const crime = {
        id: "some:tag:id",
        name: "Crime",
        tag_id: "nationals.1234"
    };
    const murder = {
        id: "some:other:tag:id",
        name: "Murder",
        tag_id: "nationals.12345"
    };

    before(done => {
        hl(utils.given(db, 'tag', crime))
            .flatMap(() => hl(utils.given(db, "tag", murder)))
            .toCallback(done);
    });

    it("Regex returns a section", (done) => {
        server
            .get("/tag-ids?filter=Crime")
            .end((err, res) => {
                assert.equal(res.body.length, 1);
                assert.equal(res.body[0].id, "some:tag:id");
                assert.equal(res.body[0].name, "Crime");
                assert.equal(res.body[0].tag_id, "nationals.1234");
                done();
            });
    });

    it("Regex fails to return a section", (done) => {
        server
            .get("/tag-ids?filter=newdsf s")
            .end((err, res) => {
                assert.deepEqual(res.body, []);
                done();
            });
    });

    it("gives back all sections for a publication", (done) => {
        server
            .get("/tag-ids")
            .end((err, res) => {
                assert.equal(res.body.length, 2);
                done();
            });
    });
});
