"use strict";

const server = require("./setup");
let assert = require("chai").assert;
let R = require("ramda");

describe('Schema Component', () => {
    it('should get the article schema with correct reference URLs', (done) => {
        server
            .get('/schemas/article')
            .end((err, res) => {
                assert.equal(res.body.id, '/article');
                assert.isOk(R.match(/http:\/\/.*\/schemas\/article/, R.head(res.body.oneOf).$ref));
                done();
            });
    });

    it('should fail gracefully if schema does not exist', (done) => {
        server
            .get('/schemas/articleeeeeeee')
            .end((err, res) => {
                assert.equal(res.body.code, 'ResourceNotFound');
                assert.equal(res.body.message, 'No schema found');
                done();
            });
    });

    it('should get a JSON object containing all available schemas', (done) => {
        server
            .get('/schemas')
            .end((err, res) => {
                assert.isOk(R.test(/http:\/\/.*\/schemas\/article/, res.body.article));
                assert.isOk(R.test(/http:\/\/.*\/schemas\/news/, res.body.news));
                assert.isOk(R.test(/http:\/\/.*\/schemas\/opinion/, res.body.opinion));
                assert.isOk(R.test(/http:\/\/.*\/schemas\/text/, res.body.text));
                done();
            });
    });
});
