'use strict';

const assert = require('chai').assert;
const rewire = require('rewire');
const index = rewire('../../lib/get/article');

describe('article', () => {

    describe('getWidgetIds', () => {

        const getWidgetIds = index.__get__('getWidgetIds');

        const config = {
            widgetIds: {
                default: {
                    online: 9390668, offline: 9438256
                },
                regionals: {
                    '1': {
                        online: 9613685, offline: 9613695
                    }
                },
                nationals: {
                    '2': {
                        online: 4705627, offline: 5478357
                    }
                }
            }
        };

        it('removes return default when publication id not found', () => {
            assert.deepEqual(getWidgetIds(config, 'nationals', '3'), {
                online: 9390668, offline: 9438256
            });
        });

        it('removes return widgetIds when publication id isfound', () => {
            assert.deepEqual(getWidgetIds(config, 'regionals', '1'), {
                online: 9613685, offline: 9613695
            });
        });
    });

    describe('removeIsNilArticleContents', () => {

        const removeIsNilArticleContents = index.__get__('removeIsNilArticleContents');

        it('removes nulls if there are some', () => {
            const given = {
                article_contents: [
                    'not_null',
                    'not_null',
                    null,
                    'not_null',
                    null
                ]
            };
            const actual = removeIsNilArticleContents(given);
            assert.equal(actual.article_contents.length, 3);
            actual.article_contents.forEach(x => {
                assert.equal(x, 'not_null');
            });
        });
    });

});
