'use strict';

const assert = require('chai').assert;

const rewire = require('rewire');
const getGallery = rewire('../../../lib/get/gallery');
const sinon = require('sinon');

describe('Get Galleries', () => {

    getGallery.__set__('galleryQuery', sinon.stub().returns('query'));
    const db = {
        gallery: {
            findAll: sinon.stub()
        }
    };

    db.gallery.findAll
        .onFirstCall().returns(Promise.resolve(['1st gallery']))
        .onSecondCall().returns(Promise.resolve(['2nd gallery']));

    it('returns a get db query forEach gallery', () => {
        getGallery(db, [
            {
                dataValues: {
                    gallery_id: 'nationals.1234'
                }
            },
            {
                dataValues: {
                    gallery_id: 'nationals.1235'
                }
            }
        ]).then(actual => {
            const query = getGallery.__get__('galleryQuery');
            const first = actual[0];
            const second = actual[1];
            assert.equal(first[0], 'gallery');
            assert.equal(first[1], '1st gallery');
            assert.equal(second[0], 'gallery');
            assert.equal(second[1], '2nd gallery');

            assert.isTrue(db.gallery.findAll.calledTwice);
            assert.equal(db.gallery.findAll.firstCall.args[0], 'query');
            assert.equal(db.gallery.findAll.secondCall.args[0], 'query');

            assert.isTrue(query.calledTwice);
            assert.equal(query.firstCall.args[0], db);
            assert.equal(query.firstCall.args[1], 'nationals.1234');
            assert.equal(query.secondCall.args[0], db);
            assert.equal(query.secondCall.args[1], 'nationals.1235');
        });
    });
    
    it('doesn\'t fail if receives empty array', () => {
        getGallery(db, []).then(actual => assert.deepEqual(actual, []));
    });
    
    it('doesn\'t fail if receives undefined', () => {
        getGallery(db).then(actual => assert.deepEqual(actual, []));
    });
});