'use strict';

const assert = require('chai').assert;
const rewire = require('rewire');
const getImage = rewire('../../../lib/get/image');
const sinon = require('sinon');

describe('Get Images', () => {

    getImage.__set__('imageQuery', sinon.stub().returns('query'));
    const db = {
        image: {
            findAll: sinon.stub()
        }
    };

    db.image.findAll
        .onFirstCall().returns(Promise.resolve('1st image'))
        .onSecondCall().returns(Promise.resolve('2nd image'));

    it('returns a get db query forEach image', () => {
        getImage(db, [
            {
                dataValues: {
                    image_id: 'nationals.1234'
                }
            },
            {
                dataValues: {
                    image_id: 'nationals.1235'
                }
            }
        ]).then(actual => {
            const query = getImage.__get__('imageQuery');
            const first = actual[0];
            const second = actual[1];
            assert.equal(first[0], 'image');
            assert.equal(first[1], '1st image');
            assert.equal(second[0], 'image');
            assert.equal(second[1], '2nd image');

            assert.isTrue(db.image.findAll.calledTwice);
            assert.equal(db.image.findAll.firstCall.args[0], 'query');
            assert.equal(db.image.findAll.secondCall.args[0], 'query');

            assert.isTrue(query.calledTwice);
            assert.equal(query.firstCall.args[0], db);
            assert.equal(query.firstCall.args[1], 'nationals.1234');
            assert.equal(query.secondCall.args[0], db);
            assert.equal(query.secondCall.args[1], 'nationals.1235');
        });
    });

    it('doesn\'t fail if receives empty array', () => {
        getImage(db, []).then(actual => assert.deepEqual(actual, []));
    });

    it('doesn\'t fail if receives undefined', () => {
        getImage(db).then(actual => assert.deepEqual(actual, []));
    });
});