'use strict';
const assert = require('chai').assert;
const sinon = require('sinon');
const getTag = require('../../../lib/get/tag');

describe('get tags', () => {
    const stub = sinon.stub().returns(Promise.resolve([{tag: 1}, {tag: 2}, {tag: null}, {}]));
    const db = {
        article_tag: {
            findAll: stub
        },
        tag: 'tag'
    };

    it('should return an empty array if articleId is undefined', done => {
        getTag(db, undefined).then(res => {
            assert.deepEqual([], res);
            done();
        });
    });

    it('should get valid tags associated to an article', done => {
        getTag(db, 'nationals.12345').then(res => {
            assert.isTrue(stub.calledWith({ where: { article_id: 'nationals.12345' }, include: 'tag' }));
            assert.deepEqual(res, [ [ { type: 'tag' }, 1 ], [ { type: 'tag' }, 2 ] ]);
            done();
        });
    });
});