"use strict";

const assert = require("chai").assert;
const rewire = require("rewire");
const schema = rewire("../../lib/schema");
const R = require("ramda");

describe("schema", () => {

    describe("refReplace", () => {

        const refReplace = schema.__get__('refReplace');

        it("should replace all $ref keys with ref and replace reference values with full URLs", () => {
            const original = JSON.stringify({
                "key1": "value1",
                "key2": "value2",
                "key3": {
                    "$ref": "/liveEvent"
                },
                "key4": {
                    "key5": {
                        "$ref": "/opinion"
                    }
                }
            });
            const json = JSON.parse(refReplace("http://www.thisisatest.co.uk/schemas", original));
            assert.equal(R.path(['key3', 'ref'], json), "http://www.thisisatest.co.uk/schemas/liveEvent");
            assert.equal(R.path(['key4', 'key5', 'ref'], json), "http://www.thisisatest.co.uk/schemas/opinion");
        });

        it("should return a JSON object unchanged if there is no $ref key", () => {
            assert.deepEqual(JSON.parse(refReplace("test", JSON.stringify({"key1": "value1"}))), {"key1": "value1"});
        });
    });
});