'use strict';

const assert = require('chai').assert;
const faker = require('../../faker');
const rewire = require('rewire');
const sinon = require('sinon');
const createArticleContent = rewire('../../../toJSON/articleContent');

describe('articleContent JSON', function () {

    createArticleContent.__set__('createContentItem', sinon.stub().returns('I create content items'));
    const createArticleContentStub = createArticleContent.__get__('createContentItem');
    createArticleContent.__set__('createEmbeddedContent', sinon.stub().returns('::embedded'));
    const createEmbeddedContentStub = createArticleContent.__get__('createEmbeddedContent');

    const homeSectionFake = {
        url:'http://www.someurl.com'
    };

    const imageSize = {
        width: 320,
        height: 150,
        code: '1234m'
    };


    it('text and html', () => {
        const expected = createArticleContent(imageSize, faker.articleContent[0]);
        assert.equal(expected[1].data.type, 'text');
        assert.equal(expected[1].data.attributes.body, 'This is the first paragraph');
    });

    it('any other type of valid content', () => {
        const expected = createArticleContent(imageSize, faker.articleContent[1]);
        const calledWith = createArticleContentStub.args[0];

        assert.equal(expected, 'I create content items');
        assert.deepEqual(calledWith[0], {width: 320, height: 150, code: '1234m'});
        assert.deepEqual(calledWith[1], {caption: 'a big ole caption'});
        assert.deepEqual(calledWith[2], {image_id: 'nationals.6662380'});
    });

    it('Embedded type of valid content', () => {
        const expected = createArticleContent(imageSize, faker.articleContent[2], homeSectionFake, 'filename');
        const calledWith = createEmbeddedContentStub.args[0];

        assert.equal(expected[1].data, '::embedded');
        assert.deepEqual(calledWith[2], { type: 'embed', escenic_id: 12345, sub_type: 'poll' });
        assert.equal(calledWith[1], 'filename');
        assert.equal(calledWith[0], homeSectionFake);
    });

    it('article_content with no static_content and no rels', () => {
        const actual = createArticleContent(imageSize, {});
        assert.isUndefined(actual);
    });

});