'use strict';

const assert = require('chai').assert;
const createAuthor = require('../../../toJSON/author');
const R = require('ramda');

describe('Author toJSON', () => {

    it('creates a basic author', () => {
        const actual = createAuthor([{}, {
            name: 'Gimme Credit',
            id: 'mirror.12345',
            author_id: 'We don\'t need you'
        }]);
        assert.deepEqual(actual[1], {
            type: 'author',
            name: 'Gimme Credit',
            id: 12345
        });
    });

    it('creates a more showy author', () => {
        const actual = createAuthor([{}, {
            name: 'Gimme Loadsa Credit',
            url: 'profile',
            imageUrl: 'http://www.mirror.com/image',
            twitterId: 'twitterId',
            description: 'some showy desscruption',
            foo: 'other unnecessary crap',
            id:"mirror.12345"
        }]);

        assert.equal(actual[1].id, 12345);
        assert.equal(actual[1].name, 'Gimme Loadsa Credit');
        assert.equal(actual[1].url, 'profile');
        assert.equal(actual[1].imageUrl, 'https://is.mirror.com/image');
        assert.equal(actual[1].twitterId, 'twitterId');
        assert.equal(actual[1].description, 'some showy desscruption');
        assert.isTrue(R.isNil(actual[1].foo));
    });

    it('Should have null id if id is null ', ()=>{
        const actual = createAuthor([{}, {
            name: 'Gimme Loadsa Credit',
            url: 'profile',
            imageUrl: 'http://www.mirror.com/image',
            twitterId: 'twitterId',
            description: 'some showy desscruption',
            foo: 'other unnecessary crap',
            id:null
        }]);

        assert.equal(actual[1].id, null);
    });

    it('Should have null id if id is falsy', ()=>{
        const actual = createAuthor([{}, {
            name: 'Gimme Loadsa Credit',
            url: 'profile',
            imageUrl: 'http://www.mirror.com/image',
            twitterId: 'twitterId',
            description: 'some showy desscruption',
            foo: 'other unnecessary crap',
            id:false
        }]);

        assert.equal(actual[1].id, null);
    });

    it('Should have null id if id is malformed', ()=>{
        const actual = createAuthor([{}, {
            name: 'Gimme Loadsa Credit',
            url: 'profile',
            imageUrl: 'http://www.mirror.com/image',
            twitterId: 'twitterId',
            description: 'some showy desscruption',
            foo: 'other unnecessary crap',
            id:'whatever you might find . here which is not a number'
        }]);

        assert.equal(actual[1].id, null);
    });
});
