'use strict';

const assert = require('chai').assert;
const rewire = require('rewire');
const sinon = require('sinon');
const createContentItem = rewire('../../../toJSON/contentItem');

describe('contentItem JSON', function () {

    createContentItem.__set__('createVideo', sinon.stub().returns('I make videos'));
    const createVideoStub = createContentItem.__get__('createVideo');

    createContentItem.__set__('createSocial', sinon.stub().returns('I make instagrams and tweets'));
    const createSocial = createContentItem.__get__('createSocial');

    it('should create video using the correct args', () => {
        const videoContentItem = {
            video_id: 'nationals.4328934',
            video: {
                id: 'nationals.4328934'
            }
        };
        const actual = createContentItem({}, {alttext: 'some alttext'}, videoContentItem);
        const calledWith = createVideoStub.args[0];

        assert.equal(actual, 'I make videos');
        assert.equal(actual, 'I make videos');
        assert.equal(calledWith[0][1].id, 'nationals.4328934');
        assert.equal(calledWith[0][0].static_content.alttext, 'some alttext');
    });

    it('should create an image placeholder', () => {
        const imageContentItem = {
            image_id: 'nationals.4328934'
        };
        const actual = createContentItem({}, {alttext: 'some alttext'}, imageContentItem);
        assert.equal(actual[1].image_id, 'nationals.4328934');
        assert.equal(actual[1].static_content.altText, 'some alttext');
        assert.equal(actual[1].noContent, true);
    });

    it('should create a gallery placeholder', () => {
        const galleryContentItem = {
            gallery_id: 'nationals.4328934'
        };
        const actual = createContentItem({}, {alttext: 'some alttext'}, galleryContentItem);
        assert.equal(actual[1].gallery_id, 'nationals.4328934');
        assert.equal(actual[1].static_content.alttext, 'some alttext');
        assert.equal(actual[1].noContent, true);
    });

    it('should return undefined if no matching case for type', () => {
        const somethingContentItem = {
            something_id: 'nationals.4328934'
        };
        const actual = createContentItem({}, {alttext: 'some alttext'}, somethingContentItem);
        assert.equal(actual, undefined);
    });

    describe("Instagrams and tweets", () => {

        beforeEach(() => createSocial.reset());
        
        it("tweet", () => {
            const tweet = {
                tweet_id: '28934',
                tweet: {
                    tweet_data: '28asdf934'
                }
            };
            const actual = createContentItem({}, void 0, tweet);
            assert.equal(actual, "I make instagrams and tweets");
            const calledWith = createSocial.args[0];
            assert.equal(calledWith[0][0].type, "tweet");
            assert.equal(calledWith[0][1].tweet_data, "28asdf934");
        });

        it("instagram", () => {
            const instagram = {
                instagram_id: '28934',
                instagram: {
                    instagram_data: '28asdf934'
                }
            };
            const actual = createContentItem({}, void 0, instagram);
            assert.equal(actual, "I make instagrams and tweets");
            const calledWith = createSocial.args[0];
            assert.equal(calledWith[0][0].type, "instagram");
            assert.equal(calledWith[0][1].instagram_data, "28asdf934");
        });
    });

});