'use strict';

const assert = require('chai').assert;
const expect = require('chai').expect;

const faker = require('../../faker');
const createEmbed = require('../../../toJSON/embed');

const embeddedItemFake = faker['embeddedType'];
const url = 'http://www.mirror.co.uk/some/section/some/id';
const filename = 'filename';
const name = 'mirror';

const homeSection = {
    url,
    publication:{
        name
    }
};

describe('Embed JSON Unit Tests', () => {
    it('Should return a correctly formed JSON', () =>{
        const actual = createEmbed(homeSection, filename, embeddedItemFake);

        // structure
        expect(actual).to.have.property('type');
        expect(actual).to.have.property('attributes');
        expect(actual).to.have.property('links');

        // types
        expect(actual.type).to.be.a('string');
        expect(actual.id).to.be.a('number');
        expect(actual.attributes).to.be.an('object');
        expect(actual.links).to.be.an('object');
        
        // values
        assert.equal(actual.type,'embed');
        assert.equal(actual.id, 12345);
        assert.equal(actual.attributes.subType, 'poll');
        assert.equal(actual.attributes.label, 'Poll');
        assert.equal(actual.links.url, `${url}${filename}/embedded-webview/${name}-12345`);

    });
});