'use strict';

const assert = require('chai').assert;
const rewire = require('rewire');
const sinon = require('sinon');
const R = require('ramda');
const gallery = rewire('../../../toJSON/gallery');

describe('Gallery toJSON', () => {

    gallery.__set__('createGalleryContent', sinon.stub().returns([{}, 'gallery content']));
    const createGalleryContent = gallery.__get__('createGalleryContent');

    const config = {};

    beforeEach(() => {
        createGalleryContent.reset();
    });

    const basicGallery = {
        id : 'nationals.1111',
        escenic_id: 1111,
        title: 'test title',
        gallery_contents: [],
        last_modified_date: new Date('2016-06-09T07:50:11.000Z')
    };

    const meta = {
        "type": "gallery"
    };

    it('basic gallery with no content builds a meta data object', () => {
        const actual = gallery(config, [meta, basicGallery]);
        assert.equal(actual[0].id, 'nationals.1111');
        assert.equal(actual[0].lastModifiedDate, basicGallery.last_modified_date);
        assert.equal(actual[0].type, 'gallery');
    });

    it('basic gallery with no content', () => {
        const actual = gallery(config, [meta, basicGallery]);
        assert.equal(actual[1].data.type, 'gallery');
        assert.equal(actual[1].data.id, 1111);
        assert.equal(actual[1].data.attributes.title, 'test title');
        assert.isNull(actual[1].data.attributes.leadMedia);
    });

    it('basic gallery with no content and article specific title', () => {
        const given = R.assoc('article_relations', [{static_content: {title: 'a different test title'}}], basicGallery);
        const actual = gallery(config, [meta, given]);
        assert.equal(actual[1].data.type, 'gallery');
        assert.equal(actual[1].data.id, 1111);
        assert.equal(actual[1].data.attributes.title, 'a different test title');
        assert.isNull(actual[1].data.attributes.leadMedia);
    });
    
    it('gallery with 3 gallery_content items', () => {
        const given = R.assoc('gallery_contents', ['1st content', '2nd content', '3rd content'], basicGallery);
        const actual = gallery(config, [meta, given]);

        assert.equal(actual[1].included.length, 2);
        assert.equal(actual[1].data.attributes.leadMedia, 'gallery content');
        actual[1].included.forEach(item => {
            assert.equal(item, 'gallery content');
        });
        assert.equal(actual[1].included.length, 2);
        assert.isTrue(createGalleryContent.calledThrice);
    });

});