"use strict";

let getLastUpdated = require("../../../toJSON/getLastUpdated");
let assert = require("chai").assert;

describe("Unit toJSON GetLastUpdated()", () => {
    
    const articleDate = "2016-10-05 12:27:28.804000";
    
    it("returns the last updateddate if array is empty", () => {
        const actual = getLastUpdated(articleDate, []);
        assert.equal(actual, articleDate);
    });

    it("doesn't change as dates are in the past", () => {
        const metaOfItemWithDateInPast = {
            "lastModifiedDate": "2016-10-05 11:27:28.804000"
        };

        const actual = getLastUpdated(articleDate, [[metaOfItemWithDateInPast]]);
        assert.equal(actual, articleDate);
    });

    it("updates date for future date", () => {
        const metaOfItemWithDateInFuture = {
            "lastModifiedDate": "2016-10-05 15:27:28.804000"
        };
        const actual = getLastUpdated(articleDate, [[metaOfItemWithDateInFuture]]);
        assert.equal(actual, "2016-10-05 15:27:28.804000");
    });

    it("shouldn't fail if the initial date is undefined", () => {
        const actual = getLastUpdated(void 0, []);
        assert.isUndefined(actual);
    });

    it("shouldn't lose the date if the last modified doesn't exist", () => {
        const meta = {};
        const actual = getLastUpdated(articleDate, [meta]);
        assert.equal(actual, articleDate);
    });
});
