'use strict';

const assert = require('chai').assert;
const faker = require('../../faker');
const rewire = require('rewire');
let sinon = require("sinon");
const createHtml = rewire('../../../toJSON/html');

describe('Html JSON', function () {

    createHtml.__set__("createSocial", sinon.stub().returns("tweetOrInstagram"));
    let createSocial = createHtml.__get__("createSocial");

    beforeEach(() => createSocial.reset());

    it('should build a meta data object', function () {
        const actual = createHtml([{}, faker.html]);

        const meta = actual[0];
        assert.equal(meta.type, 'html');
        assert.equal(meta.lastModifiedDate, faker.html.last_modified_date);
        assert.equal(meta.id, faker.html.id);
    });

    it('basic html', () => {
        const actual = createHtml([{}, faker.html]);
        assert.deepEqual(actual[1], {
            data: {
                type: 'embed',
                id: 8392,
                attributes: {
                    label: "Interactive Content",
                    subType: "interactiveHTML"
                },
                links:{
                    url: "embeddedHTMLurlPlaceholder"
                }
            }
        });
    });

    it("it's a tweet", () => {
        const html = {
            "html_content_item": {
                "tweet": "it's a tweet"
            },
            "id": "2fo330"
        };

        const actual = createHtml([{}, html]);
        assert.equal(actual, "tweetOrInstagram");
        assert.equal(createSocial.callCount, 1);
        assert.equal(createSocial.firstCall.args[0][0].type, "tweet");
        assert.equal(createSocial.firstCall.args[0][0].source_id, "2fo330");
        assert.equal(createSocial.firstCall.args[0][1], "it's a tweet");
    });
    
    it("it's an instagram", () => {
        const html = {
            "html_content_item": {
                "instagram": "it's an instagram"
            },
            "id": "2fo330"
        };
        const actual = createHtml([{}, html]);
        assert.equal(actual, "tweetOrInstagram");
        assert.equal(createSocial.callCount, 1);
        assert.equal(createSocial.firstCall.args[0][0].type, "instagram");
        assert.equal(createSocial.firstCall.args[0][0].source_id, "2fo330");
        assert.equal(createSocial.firstCall.args[0][1], "it's an instagram");
    });
});
