'use strict';

const assert = require('chai').assert;
const rewire = require('rewire');
const sinon = require('sinon');
const mapper = rewire('../../../toJSON/mapper');

describe('Mapper toJSON', () => {

    mapper.__set__('createGallery', sinon.stub().returns('gallery'));
    mapper.__set__('createArticle', sinon.stub().returns('article'));
    mapper.__set__('createAuthor', sinon.stub().returns('author'));
    mapper.__set__('createImage', sinon.stub().returns('image'));

    const createGallery = mapper.__get__('createGallery');
    const createArticle = mapper.__get__('createArticle');
    const createAuthor = mapper.__get__('createAuthor');
    const createImage = mapper.__get__('createImage');

    const config = {imageDimensions: {}};

    beforeEach(() => {
        createArticle.reset();
        createGallery.reset();
        createAuthor.reset();
        createImage.reset();
    });

    it('article', () => {
        const tuple = [{
            "type": 'news'
        }, {}];
        const actual = mapper(config, tuple);
        assert.equal(actual, 'article');
        assert.isTrue(createArticle.calledOnce);
        assert.isTrue(createArticle.calledWith(config, tuple));
        sinon.assert.notCalled(createGallery);
        sinon.assert.notCalled(createImage);
        sinon.assert.notCalled(createAuthor);
    });

    it('should transform live event', () => {
        const tuple = [{
            "type": "live-event"
        }, {}];
        const actual = mapper(config, tuple);
        assert.strictEqual(actual, 'article');
        assert.isTrue(createArticle.calledOnce);
        assert.isTrue(createArticle.calledWith(config, tuple));
        sinon.assert.notCalled(createGallery);
        sinon.assert.notCalled(createImage);
        sinon.assert.notCalled(createAuthor);
    });

    it('gallery', () => {
        const tuple = [{
            "type": "gallery"
        }, {
            gallery_id: 'nationals.11235813'
        }];
        const actual = mapper(config, tuple);
        assert.equal(actual, 'gallery');
        assert.isTrue(createGallery.calledOnce);
        assert.isTrue(createGallery.calledWith(config.imageDimensions, tuple));
        sinon.assert.notCalled(createArticle);
        sinon.assert.notCalled(createImage);
        sinon.assert.notCalled(createAuthor);
    });

    it('image', () => {
        const tuple = [{
            "type": "image"
        }, {
            image_id: 'nationals.98765'
        }];
        const actual = mapper(config, tuple);
        assert.equal(actual, 'image');
        assert.isTrue(createImage.calledOnce);
        assert.isTrue(createImage.calledWith(config.imageDimensions, tuple));
        sinon.assert.notCalled(createArticle);
        sinon.assert.notCalled(createGallery);
        sinon.assert.notCalled(createAuthor);
    });

    it('author', () => {
        const tuple = [{
            "type": 'author'
        }, {
            author_id: 'nationals.3691215'
        }];
        const actual = mapper(config, tuple);
        assert.equal(actual, 'author');
        assert.isTrue(createAuthor.calledOnce);
        assert.isTrue(createAuthor.calledWith(tuple));
        sinon.assert.notCalled(createArticle);
        sinon.assert.notCalled(createGallery);
        sinon.assert.notCalled(createImage);
    });

});
