'use strict';

const assert = require('chai').assert;
const rewire = require('rewire');
const createSocial = rewire('../../../toJSON/social');

describe('Social media JSON', function () {

    it('basic tweet', () => {

        const tweet = {
            id:'12345678912345',
            data: {
                content: '140 chars of nonsense',
                id_str: '12345678912345'
            }
        };

        const actual = createSocial([{
            "type": "tweet"
        }, tweet]);
        assert.deepEqual(actual[1], {
            data: {
                type: 'tweet',
                id: '12345678912345',
                attributes: {
                    content: '140 chars of nonsense',
                    id_str: '12345678912345',
                    tweetId: '12345678912345'
                }
            }
        });
    });

    it('instagram from html', () => {

        const instgram = {
            id:'dfiow148',
            data: {
                instagramId: 'dfiow148',
                caption: '140 chars of nonsense',
                username: 'someUser',
                url: 'https://www.instagram.com/p/dfiow148',
                image_url: 'imageUrl',
                profileImageUrl: 'profile'
            }
        };

        const actual = createSocial([{
            "type": "instagram",
            "source_id": "dfiow148"
        }, instgram]);
        assert.deepEqual(actual[1], {
            data: {
                type: 'instagram',
                id: 'dfiow148',
                attributes: {
                    instagramId: 'dfiow148',
                    caption: '140 chars of nonsense',
                    username: 'someUser',
                    imageUrl: 'imageUrl',
                    profileImageUrl: 'profile'
                },
                links: {
                    url: 'https://www.instagram.com/p/dfiow148/embed'
                }
            }
        });
    });
});
