'use strict';

const assert = require('chai').assert;
const faker = require('../../faker');
const rewire = require('rewire');
const createVideo = rewire('../../../toJSON/video');

describe('Video JSON', function () {

    it('should build a meta data object', function () {
        const actual = createVideo([{}, faker.video]);
        const meta = actual[0];
        assert.equal(meta.type, 'video');
        assert.equal(meta.lastModifiedDate, faker.video.last_modified_date);
        assert.equal(meta.id, faker.video.id);
    });

    it('basic video', () => {
        const actual = createVideo([{}, faker.video]);
        assert.equal(actual[1].data.type, 'video');
        assert.equal(actual[1].data.id, 4328934);
        assert.equal(actual[1].data.attributes.subType, 'youtubeVideo');
        assert.equal(actual[1].data.attributes.videoId, 'nf1j345131l3k451');
        assert.equal(actual[1].data.attributes.title, 'test-title');
    });

    it('video with inline static content', () => {
        const actual = createVideo([{
            "type": "video",
            "static_content": {
                title: 'an article specific title to a video'
            }
        }, faker.video]);
        assert.equal(actual[1].data.type, 'video');
        assert.equal(actual[1].data.id, 4328934);
        assert.equal(actual[1].data.attributes.subType, 'youtubeVideo');
        assert.equal(actual[1].data.attributes.videoId, 'nf1j345131l3k451');
        assert.equal(actual[1].data.attributes.title, 'an article specific title to a video');
    });

});