'use strict';

const R = require('ramda');
let createContentItem = require('./contentItem');
let createEmbeddedContent = require('./embed');

const isEmbedded = articleContent => !R.isNil(articleContent.static_content) && articleContent.static_content.type === 'embed';
const isText = articleContent => !R.isNil(articleContent.static_content);
const contentItemMissing = articleContent => !R.isNil(articleContent.content_item_id);
const isContentItem = articleContent => !R.isNil(articleContent.content_item);

module.exports = function (config, articleContent, homeSection, filename) {
    if(isEmbedded(articleContent)){
        const staticContent = articleContent.static_content;
        const meta = {
            "type": "embed"
        };
        return [meta, {
            data: createEmbeddedContent(homeSection, filename, staticContent)
        }];
    }else if (isContentItem(articleContent)) {
        return createContentItem(config, articleContent.static_content, articleContent.content_item);
    } else if(contentItemMissing(articleContent)) {
        return null;
    }else if(isText(articleContent)) {
        const staticContent = articleContent.static_content;
        const meta = {
            "type": "text"
        };
        return [meta, {
            data: {
                type: staticContent.type,
                attributes: {
                    body: staticContent.body
                }
            }
        }];
    }
};