'use strict';

const R = require('ramda');
let createVideo = require('./video');
let createQuiz = require('./quiz');
let createSocial = require('./social');

module.exports = function (config, staticContent, contentItem) {
    const contentItemWithStaticContent = R.assoc('static_content', staticContent, contentItem);

    const meta = {
        "static_content": staticContent
    };
    
    if(!R.isNil(contentItem.image_id)) {
        let image = R.assoc('noContent', true, contentItemWithStaticContent);
        const altText = R.path(["alttext"], staticContent);
        if(altText) image.static_content.altText = altText;
        return Array.of({}, image);
    }
    if(!R.isNil(contentItem.gallery_id)) {
        return Array.of({}, R.assoc('noContent', true, contentItemWithStaticContent));
    }
    if(!R.isNil(contentItem.video_id)) {
        return createVideo([meta, contentItem.video]);
    }
    if(!R.isNil(contentItem.html_id)) {
        return Array.of({}, R.assoc('noContent', true, contentItemWithStaticContent));
    }
    if(!R.isNil(contentItem.quiz)) {
        return createQuiz([meta, contentItem.quiz]);
    }
    if(!R.isNil(contentItem.tweet_id)) {
        return createSocial([R.merge(meta, {"type": "tweet"}), contentItem.tweet]);
    }
    if(!R.isNil(contentItem.instagram_id)) {
        return createSocial([R.merge(meta, {"type": "instagram"}), contentItem.instagram]);
    }
};
